/*
 *  VME Linux/m68k TFTP Loader
 *
 *  (c) Copyright 1998 by Nick Holgate
 *
 *  This file is subject to the terms and conditions of the GNU General
 *  Public License.  See the file COPYING for more details.
 */

/*--------------------------------------------------------------------------*/

#include "defs.h"

/*--------------------------------------------------------------------------*/
/*  Program Entry
 */

__asm__(".text\n"
__ALIGN_STR "\n"
".globl " SYMBOL_NAME_STR(_start) ";\n"
SYMBOL_NAME_STR(_start) ":				\n\
										\n\
	movem.l	%d0-%d7/%a0-%a6,-(%sp)		\n\
	move.l	%sp,-(%sp)					\n\
	jsr	(" SYMBOL_NAME_STR(Main) ");	\n\
");

/*-----------------------------< end of file >------------------------------*/
